;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "auto-complete" "20251123.1919"
  "Auto Completion for GNU Emacs."
  '((emacs "25.1")
    (popup "0.5.8"))
  :url "https://github.com/auto-complete/auto-complete"
  :commit "1dbfb343412f9444dcd2d9a08b7b42c7270c9547"
  :revdesc "1dbfb343412f"
  :keywords '("completion" "convenience")
  :authors '(("Tomohiro Matsuyama" . "m2ym.pub@gmail.com"))
  :maintainers '(("Jen-Chieh Shen" . "jcs090218@gmail.com")))
